# Generated by h2py from /usr/include/dlfcn.h
_DLFCN_H = 1

# Included from features.h
_FEATURES_H = 1
def __GLIBC_USE(F): return __GLIBC_USE_ ## F

_DEFAULT_SOURCE = 1
_ISOC23_SOURCE = 1
_ISOC95_SOURCE = 1
_ISOC99_SOURCE = 1
_ISOC11_SOURCE = 1
_ISOC23_SOURCE = 1
_ISOC2Y_SOURCE = 1
_POSIX_SOURCE = 1
_POSIX_C_SOURCE = 202405L
_XOPEN_SOURCE = 800
_XOPEN_SOURCE_EXTENDED = 1
_LARGEFILE64_SOURCE = 1
_DEFAULT_SOURCE = 1
_ATFILE_SOURCE = 1
_DYNAMIC_STACK_SIZE_SOURCE = 1
_DEFAULT_SOURCE = 1
__GLIBC_USE_ISOC2Y = 1
__GLIBC_USE_ISOC2Y = 0
__GLIBC_USE_ISOC23 = 1
__GLIBC_USE_ISOC23 = 0
__USE_ISOC11 = 1
__USE_ISOC99 = 1
__USE_ISOC95 = 1
__USE_ISOC11 = 1
__USE_ISOCXX11 = 1
__USE_ISOC99 = 1
__USE_POSIX_IMPLICITLY = 1
_POSIX_SOURCE = 1
_POSIX_C_SOURCE = 202405L
_POSIX_SOURCE = 1
_POSIX_C_SOURCE = 2
_POSIX_C_SOURCE = 199506L
_POSIX_C_SOURCE = 200112L
_POSIX_C_SOURCE = 200809L
_POSIX_C_SOURCE = 202405L
__USE_POSIX_IMPLICITLY = 1
_POSIX_SOURCE = 1
_POSIX_C_SOURCE = 199506L
__USE_POSIX = 1
__USE_POSIX2 = 1
__USE_POSIX199309 = 1
__USE_POSIX199506 = 1
__USE_XOPEN2K = 1
__USE_ISOC95 = 1
__USE_ISOC99 = 1
__USE_XOPEN2K8 = 1
_ATFILE_SOURCE = 1
__USE_XOPEN2K24 = 1
__USE_XOPEN = 1
__USE_XOPEN_EXTENDED = 1
__USE_UNIX98 = 1
_LARGEFILE_SOURCE = 1
__USE_XOPEN2K8 = 1
__USE_XOPEN2K8XSI = 1
__USE_XOPEN2K24 = 1
__USE_XOPEN2K24XSI = 1
__USE_XOPEN2K = 1
__USE_XOPEN2KXSI = 1
__USE_ISOC95 = 1
__USE_ISOC99 = 1
__USE_XOPEN_EXTENDED = 1
__USE_LARGEFILE = 1
__USE_LARGEFILE64 = 1
__USE_FILE_OFFSET64 = 1

# Included from features-time64.h

# Included from bits/wordsize.h
__WORDSIZE = 64
__WORDSIZE = 32
__WORDSIZE32_SIZE_ULONG = 0
__WORDSIZE32_PTRDIFF_LONG = 0
__WORDSIZE_TIME64_COMPAT32 = 1
__SYSCALL_WORDSIZE = 64

# Included from bits/timesize.h
__TIMESIZE = 64
__TIMESIZE = __WORDSIZE
__USE_TIME_BITS64 = 1
__USE_TIME_BITS64 = 1
__USE_TIME64_REDIRECTS = 1
__USE_MISC = 1
__USE_ATFILE = 1
__USE_DYNAMIC_STACK_SIZE = 1
__USE_GNU = 1
__USE_FORTIFY_LEVEL = 3
__USE_FORTIFY_LEVEL = 2
__USE_FORTIFY_LEVEL = 1
__USE_FORTIFY_LEVEL = 0
__GLIBC_USE_DEPRECATED_GETS = 0
__GLIBC_USE_DEPRECATED_GETS = 1
__GLIBC_USE_DEPRECATED_SCANF = 1
__GLIBC_USE_DEPRECATED_SCANF = 0
__GLIBC_USE_C23_STRTOL = 1
__GLIBC_USE_C23_STRTOL = 0

# Included from stdc-predef.h
_STDC_PREDEF_H = 1
__STDC_IEC_559__ = 1
__STDC_IEC_60559_BFP__ = 201404L
__STDC_IEC_559__ = 1
__STDC_IEC_60559_BFP__ = 201404L
__STDC_IEC_559_COMPLEX__ = 1
__STDC_IEC_60559_COMPLEX__ = 201404L
__STDC_IEC_559_COMPLEX__ = 1
__STDC_IEC_60559_COMPLEX__ = 201404L
__STDC_ISO_10646__ = 201706L
__GNU_LIBRARY__ = 6
__GLIBC__ = 2
__GLIBC_MINOR__ = 43

# Included from sys/cdefs.h
_SYS_CDEFS_H = 1
def __glibc_has_attribute(attr): return __has_attribute (attr)

def __glibc_has_attribute(attr): return 0

def __glibc_has_builtin(name): return __has_builtin (name)

def __glibc_has_builtin(name): return 0

def __glibc_has_extension(ext): return __has_extension (ext)

def __glibc_has_extension(ext): return 0

def __NTH(fct): return fct

def __NTHNL(fct): return fct

def __NTH(fct): return fct

def __P(args): return args

def __PMT(args): return args

def __STRING(x): return #x

def __bos(ptr): return __builtin_object_size (ptr, __USE_FORTIFY_LEVEL > 1)

def __bos0(ptr): return __builtin_object_size (ptr, 0)

def __glibc_objsize0(__o): return __builtin_dynamic_object_size (__o, 0)

def __glibc_objsize(__o): return __builtin_dynamic_object_size (__o, 1)

def __glibc_objsize0(__o): return __bos0 (__o)

def __glibc_objsize(__o): return __bos (__o)

def __glibc_unsigned_or_positive(__l): return \

__fortify_use_clang = 1
def __fortify_clang_pass_object_size_n(n): return \

__fortify_clang_pass_object_size0 = \
  __fortify_clang_pass_object_size_n (0)
__fortify_clang_pass_object_size = \
  __fortify_clang_pass_object_size_n (__USE_FORTIFY_LEVEL > 1)
def __fortify_clang_pass_dynamic_object_size_n(n): return \

__fortify_clang_pass_dynamic_object_size0 = \
  __fortify_clang_pass_dynamic_object_size_n (0)
__fortify_clang_pass_dynamic_object_size = \
  __fortify_clang_pass_dynamic_object_size_n (1)
def __fortify_clang_unavailable(__msg): return \

__fortify_use_clang = 0
def __warnattr(msg): return __attribute__((__warning__ (msg)))

__flexarr = []
__glibc_c99_flexarr_available = 1
__flexarr = []
__glibc_c99_flexarr_available = 1
__flexarr = [0]
__glibc_c99_flexarr_available = 1
__flexarr = [1]
__glibc_c99_flexarr_available = 0
def __ASMNAME(cname): return __ASMNAME2 (__USER_LABEL_PREFIX__, cname)

def __attribute__(xyz): return  

def __attribute_alloc_size__(params): return \

def __attribute_alloc_size__(params): return  

def __attribute_alloc_align__(param): return \

def __attribute_alloc_align__(param): return  

def __attribute_deprecated_msg__(msg): return \

def __attribute_deprecated_msg__(msg): return __attribute_deprecated__

def __attribute_format_arg__(x): return __attribute__ ((__format_arg__ (x)))

def __attribute_format_arg__(x): return  

def __nonnull(params): return __attribute_nonnull__ (params)

def __glibc_unlikely(cond): return __builtin_expect ((cond), 0)

def __glibc_likely(cond): return __builtin_expect ((cond), 1)

def __glibc_unlikely(cond): return (cond)

def __glibc_likely(cond): return (cond)

def __attribute_copy__(arg): return __attribute__ ((__copy__ (arg)))


# Included from bits/long-double.h
__LDOUBLE_REDIRECTS_TO_FLOAT128_ABI = 0
def __LDBL_REDIR_DECL(name): return \

def __LDBL_REDIR2_DECL(name): return \

__LDBL_COMPAT = 1
def __LDBL_REDIR2_DECL(name): return \

def __LDBL_REDIR_DECL(name): return \

def __glibc_macro_warning(message): return \

__HAVE_GENERIC_SELECTION = 1
__HAVE_GENERIC_SELECTION = 0
def __attr_access_none(argno): return __attribute__ ((__access__ (__none__, argno)))

__USE_LARGEFILE = 1
__USE_LARGEFILE64 = 1
__USE_EXTERN_INLINES = 1

# Included from gnu/stubs.h

# Included from gnu/stubs-32.h

# Included from bits/dlfcn.h
RTLD_LAZY = 0x00001
RTLD_NOW = 0x00002
RTLD_BINDING_MASK = 0x3
RTLD_NOLOAD = 0x00004
RTLD_DEEPBIND = 0x00008
RTLD_GLOBAL = 0x00100
RTLD_LOCAL = 0
RTLD_NODELETE = 0x01000

# Included from bits/dl_find_object.h
DLFO_STRUCT_HAS_EH_DBASE = 0
DLFO_STRUCT_HAS_EH_DBASE = 1
DLFO_STRUCT_HAS_EH_COUNT = 0
LM_ID_BASE = 0
LM_ID_NEWLM = -1



#!/usr/bin/env python2

# Fix Python script(s) to reference the interpreter via /usr/bin/env python.
# Warning: this overwrites the file without making a backup.

import sys
import re


def main():
    for filename in sys.argv[1:]:
        try:
            f = open(filename, 'r')
        except IOError, msg:
            print filename, ': can\'t open :', msg
            continue
        line = f.readline()
        if not re.match('^#! */usr/local/bin/python', line):
            print filename, ': not a /usr/local/bin/python script'
            f.close()
            continue
        rest = f.read()
        f.close()
        line = re.sub('/usr/local/bin/python',
                      '/usr/bin/env python', line)
        print filename, ':', repr(line)
        f = open(filename, "w")
        f.write(line)
        f.write(rest)
        f.close()

if __name__ == '__main__':
    main()
